# Spatial Access

![tag](https://img.shields.io/github/v/release/pysal/access?include_prereleases&sort=semver)
[![Documentation](https://img.shields.io/static/v1.svg?label=docs&message=current&color=9cf)](http://pysal.org/access/)
[![Continuous Integration](https://github.com/pysal/access/actions/workflows/testing.yml/badge.svg)](https://github.com/pysal/access/actions/workflows/testing.yml)

This package provides classical and novel measures of spatial accessibility to services.

For full documentation, see [here](https://pysal.org/access/).
